@@ -6,14 +6,13 @@ from nsj_rest_lib.controller.route_base import RouteBase
 from nsj_rest_lib.dto.dto_base import DTOBase
 from nsj_rest_lib.entity.entity_base import EntityBase
 from nsj_rest_lib.exception import (
-    DTOConfigException,
     MissingParameterException,
     NotFoundException,
 )
 from nsj_rest_lib.injector_factory_base import NsjInjectorFactoryBase
 from nsj_rest_lib.settings import get_logger
 
-from nsj_gcf_utils.json_util import json_dumps, json_loads, JsonLoadException
+from nsj_gcf_utils.json_util import json_dumps, JsonLoadException
 from nsj_gcf_utils.rest_error_util import format_json_error
 
 
@@ -28,6 +27,7 @@ class PutRoute(RouteBase):
         injector_factory: NsjInjectorFactoryBase = NsjInjectorFactoryBase,
         service_name: str = None,
         handle_exception: Callable = None,
+        custom_before_update: Callable = None,
         custom_after_update: Callable = None,
     ):
         super().__init__(
@@ -40,6 +40,7 @@ class PutRoute(RouteBase):
             service_name=service_name,
             handle_exception=handle_exception,
         )
+        self.custom_before_update = custom_before_update
         self.custom_after_update = custom_after_update
 
     def handle_request(self, id):
@@ -51,9 +52,10 @@ class PutRoute(RouteBase):
             try:
                 # Recuperando os dados do corpo da rquisição
                 data = request.json
+                data["generate_default_pk_value"] = False
 
                 # Convertendo os dados para o DTO
-                data = self._dto_class(**data, generate_default_pk_value=False)
+                data = self._dto_class(**data)
 
                 # Montando os filtros de particao de dados
                 partition_filters = {}
@@ -73,6 +75,7 @@ class PutRoute(RouteBase):
                     dto=data,
                     id=id,
                     aditional_filters=partition_filters,
+                    custom_before_update=self.custom_before_update,
                     custom_after_update=self.custom_after_update,
                 )
 
