@@ -6,6 +6,7 @@ from nsj_rest_lib.settings import DATABASE_USER
 from nsj_rest_lib.settings import DATABASE_DRIVER
 from nsj_rest_lib.settings import CLOUD_SQL_CONN_NAME
 from nsj_rest_lib.settings import ENV
+from nsj_rest_lib.settings import DB_POOL_SIZE
 
 import sqlalchemy
 
@@ -14,10 +15,11 @@ def create_pool(database_conn_url):
     # Creating database connection pool
     db_pool = sqlalchemy.create_engine(
         database_conn_url,
-        pool_size=5,
-        max_overflow=2,
-        pool_timeout=30,
-        pool_recycle=1800,
+        # pool_size=DB_POOL_SIZE,
+        # max_overflow=2,
+        # pool_timeout=30,
+        # pool_recycle=1800,
+        poolclass=sqlalchemy.pool.NullPool,
     )
     return db_pool
 
@@ -30,4 +32,9 @@ else:
     else:
         database_conn_url = f"postgresql+pg8000://{DATABASE_USER}:{DATABASE_PASS}@{DATABASE_HOST}:{DATABASE_PORT}/{DATABASE_NAME}"
 
-db_pool = create_pool(database_conn_url)
+
+def default_create_pool():
+    return create_pool(database_conn_url)
+
+
+# db_pool = create_pool(database_conn_url)
