@@ -7,8 +7,14 @@ from flask import g
 
 from nsj_rest_lib.dao.dao_base import DAOBase
 from nsj_rest_lib.descriptor.dto_field import DTOFieldFilter
+from nsj_rest_lib.descriptor.dto_left_join_field import (
+    DTOLeftJoinField,
+    EntityRelationOwner,
+    LeftJoinQuery,
+)
 from nsj_rest_lib.descriptor.filter_operator import FilterOperator
 from nsj_rest_lib.dto.dto_base import DTOBase
+from nsj_rest_lib.dto.after_insert_update_data import AfterInsertUpdateData
 from nsj_rest_lib.entity.entity_base import EntityBase
 from nsj_rest_lib.entity.filter import Filter
 from nsj_rest_lib.exception import (
@@ -44,7 +50,7 @@ class ServiceBase:
         self,
         id: str,
         partition_fields: Dict[str, Any],
-        fields: Dict[str, List[str]],
+        fields: Dict[str, Set[str]],
     ) -> DTOBase:
         # Resolving fields
         fields = self._resolving_fields(fields)
@@ -84,6 +90,14 @@ class ServiceBase:
         if len(self._dto_class.list_fields_map) > 0:
             self._retrieve_related_lists([dto], fields)
 
+        # Tratando das propriedades de relacionamento left join
+        if len(self._dto_class.left_join_fields_map) > 0:
+            self._retrieve_left_join_fields(
+                [dto],
+                fields,
+                partition_fields,
+            )
+
         return dto
 
     def _resolve_field_key(
@@ -340,6 +354,15 @@ class ServiceBase:
         if len(self._dto_class.list_fields_map) > 0:
             self._retrieve_related_lists(dto_list, fields)
 
+        # Tratando das propriedades de relacionamento left join
+        # TODO Verificar se está certo passar os filtros como campos de partição
+        if len(self._dto_class.left_join_fields_map) > 0:
+            self._retrieve_left_join_fields(
+                dto_list,
+                fields,
+                filters,
+            )
+
         # Returning
         return dto_list
 
@@ -375,11 +398,15 @@ class ServiceBase:
                             f"PK field not found in DTO: {self._dto_class}"
                         )
 
+                    # Resolvendo a chave do relacionamento
+                    relation_key_field = self._dto_class.pk_field
+                    if list_field.relation_key_field is not None:
+                        relation_key_field = list_field.relation_key_field
+
                     # Making filter to relation
                     filters = {
-                        # TODO Adicionar os campos de particionamento de dados
                         list_field.related_entity_field: getattr(
-                            dto, self._dto_class.pk_field
+                            dto, relation_key_field
                         )
                     }
 
@@ -408,8 +435,8 @@ class ServiceBase:
         self,
         dto: DTOBase,
         aditional_filters: Dict[str, Any] = None,
+        custom_before_insert: Callable = None,
         custom_after_insert: Callable = None,
-        custom_after_update: Callable = None,
     ) -> DTOBase:
         return self._save(
             insert=True,
@@ -417,8 +444,8 @@ class ServiceBase:
             manage_transaction=True,
             partial_update=False,
             aditional_filters=aditional_filters,
+            custom_before_insert=custom_before_insert,
             custom_after_insert=custom_after_insert,
-            custom_after_update=custom_after_update,
         )
 
     def update(
@@ -426,7 +453,7 @@ class ServiceBase:
         dto: DTOBase,
         id: Any,
         aditional_filters: Dict[str, Any] = None,
-        custom_after_insert: Callable = None,
+        custom_before_update: Callable = None,
         custom_after_update: Callable = None,
     ) -> DTOBase:
         return self._save(
@@ -436,12 +463,17 @@ class ServiceBase:
             partial_update=False,
             id=id,
             aditional_filters=aditional_filters,
-            custom_after_insert=custom_after_insert,
+            custom_before_update=custom_before_update,
             custom_after_update=custom_after_update,
         )
 
     def partial_update(
-        self, dto: DTOBase, id: Any, aditional_filters: Dict[str, Any] = None
+        self,
+        dto: DTOBase,
+        id: Any,
+        aditional_filters: Dict[str, Any] = None,
+        custom_before_update: Callable = None,
+        custom_after_update: Callable = None,
     ) -> DTOBase:
         return self._save(
             insert=False,
@@ -450,22 +482,25 @@ class ServiceBase:
             partial_update=True,
             id=id,
             aditional_filters=aditional_filters,
+            custom_before_update=custom_before_update,
+            custom_after_update=custom_after_update,
         )
 
     def _make_fields_from_dto(self, dto: DTOBase, root_name: str = "root"):
         # Adicionando os campos normais do DTO
         fields = {root_name: set()}
-        for field in self._dto_class.fields_map:
-            if field in dto.__dict__ or self._dto_class.fields_map[field].pk:
+        for field in dto.fields_map:
+            if field in dto.__dict__:
                 fields[root_name].add(field)
 
         # Adicionando os campos de lista, contidos no DTO
-        for list_field in self._dto_class.list_fields_map:
-            if field in dto.__dict__:
+        for list_field in dto.list_fields_map:
+            if list_field in dto.__dict__:
                 list_dto = getattr(dto, list_field)
-                if len(list_dto) < 0:
+                if not list_dto:
                     continue
 
+                fields[root_name].add(list_field)
                 list_fields = self._make_fields_from_dto(list_dto[0], list_field)
                 fields = {**fields, **list_fields}
 
@@ -480,17 +515,33 @@ class ServiceBase:
         relation_field_map: Dict[str, Any] = None,
         id: Any = None,
         aditional_filters: Dict[str, Any] = None,
+        custom_before_insert: Callable = None,
+        custom_before_update: Callable = None,
         custom_after_insert: Callable = None,
         custom_after_update: Callable = None,
     ) -> DTOBase:
         try:
+            # Guardando um ponteiro para o DTO recebido
+            received_dto = dto
+
             if manage_transaction:
                 self._dao.begin()
 
             # Recuperando o DTO antes da gravação (apenas se for update, e houver um custom_after_update)
-            if not insert and custom_after_update is not None:
+            if not insert and (
+                custom_after_update is not None or custom_before_update is not None
+            ):
                 old_dto = self._retrieve_old_dto(dto, id, aditional_filters)
 
+            if custom_before_insert:
+                received_dto = copy.deepcopy(dto)
+                dto = custom_before_insert(self._dao._db, dto)
+
+            if custom_before_update:
+                if received_dto == dto:
+                    received_dto = copy.deepcopy(dto)
+                dto = custom_before_update(self._dao._db, old_dto, dto)
+
             # Convertendo o DTO para a Entity
             # TODO Refatorar para usar um construtor do EntityBase (ou algo assim, porque é preciso tratar das equivalências de nome dos campos)
             entity = dto.convert_to_entity(self._entity_class, partial_update)
@@ -610,6 +661,9 @@ class ServiceBase:
             if custom_after_insert is not None or custom_after_update is not None:
                 new_dto = self._dto_class(entity, escape_validator=True)
 
+                for list_field in dto.list_fields_map:
+                    setattr(new_dto, list_field, getattr(dto, list_field))
+
                 # Adicionando campo de conjunto
                 if (
                     self._dto_class.conjunto_field is not None
@@ -618,12 +672,18 @@ class ServiceBase:
                     value_conjunto = getattr(dto, self._dto_class.conjunto_field)
                     setattr(new_dto, self._dto_class.conjunto_field, value_conjunto)
 
+            # Montando um objeto de dados a serem passados para os códigos customizados
+            # do tipo after insert ou update
+            after_data = AfterInsertUpdateData()
+            after_data.received_dto = received_dto
+
+            # Invocando os códigos customizados do tipo after insert ou update
             if insert:
                 if custom_after_insert is not None:
-                    custom_after_insert(self._dao._db, new_dto)
+                    custom_after_insert(self._dao._db, new_dto, after_data)
             else:
                 if custom_after_update is not None:
-                    custom_after_update(self._dao._db, old_dto, new_dto)
+                    custom_after_update(self._dao._db, old_dto, new_dto, after_data)
 
             # Retornando o DTO de resposta
             return response_dto
@@ -704,20 +764,26 @@ class ServiceBase:
                 list_field.dto_post_response_type,
             )
 
+            # Resolvendo a chave do relacionamento
+            relation_key_field = entity.get_pk_field()
+            if list_field.relation_key_field is not None:
+                relation_key_field = dto.get_entity_field_name(
+                    list_field.relation_key_field
+                )
+
             # Recuperando o valor da PK da entidade principal
-            entity_pk_field = entity.get_pk_field()
-            pk_value = getattr(entity, entity_pk_field)
+            relation_key_value = getattr(entity, relation_key_field)
 
             # Montando um mapa com os campos de relacionamento (para gravar nas entidades relacionadas)
             relation_field_map = {
-                list_field.related_entity_field: pk_value,
+                list_field.related_entity_field: relation_key_value,
             }
 
             # Recuperando todos os IDs dos itens de lista já salvos no BD (se for um update)
             old_detail_ids = None
             if not insert:
                 # Montando o filtro para recuperar os objetos detalhe pré-existentes
-                relation_condiction = Filter(FilterOperator.EQUALS, pk_value)
+                relation_condiction = Filter(FilterOperator.EQUALS, relation_key_value)
 
                 relation_filter = {
                     list_field.related_entity_field: [relation_condiction]
@@ -841,6 +907,9 @@ class ServiceBase:
         unique_filter = {}
         for field in unique:
             value = getattr(dto, field)
+            # Se um dos campos for nulos, então a unique é falsa. Isso é baseado no postgres aonde null é sempre diferente de null para uniques
+            if value is None:
+                return
             unique_filter[field] = value
 
         # Convertendo o filtro para o formato de filtro de entidades
@@ -964,3 +1033,120 @@ class ServiceBase:
                     manage_transaction=False,
                     additional_filters=additional_filters,
                 )
+
+    def _retrieve_left_join_fields(
+        self,
+        dto_list: List[DTOBase],
+        fields: Dict[str, Set[str]],
+        partition_fields: Dict[str, Any],
+    ):
+        # Tratando cada dto recebido
+        for dto in dto_list:
+            # Tratando cada tipo de entidade relacionada
+            left_join_fields_map_to_query = getattr(
+                dto.__class__, "left_join_fields_map_to_query", {}
+            )
+            for left_join_query_key in left_join_fields_map_to_query:
+                left_join_query: LeftJoinQuery = left_join_fields_map_to_query[
+                    left_join_query_key
+                ]
+
+                # Verificando os fields de interesse
+                fields_necessarios = set()
+                for field in left_join_query.fields:
+                    if field in fields["root"]:
+                        fields_necessarios.add(field)
+
+                # Se nenhum dos fields registrados for pedido, ignora esse relacioanemtno
+                if len(fields_necessarios) <= 0:
+                    continue
+
+                # Getting related service instance
+                # TODO Refatorar para suportar services customizados
+                service = ServiceBase(
+                    self._injector_factory,
+                    DAOBase(
+                        self._injector_factory.db_adapter(),
+                        left_join_query.related_entity,
+                    ),
+                    left_join_query.related_dto,
+                    left_join_query.related_entity,
+                )
+
+                # Montando a lista de campos a serem recuperados na entidade relacionada
+                related_fields = set()
+                for left_join_field in left_join_query.left_join_fields:
+                    # Ignorando os campos que não estejam no retorno da query
+                    if left_join_field.name not in fields_necessarios:
+                        continue
+
+                    related_fields.add(left_join_field.related_dto_field)
+
+                related_fields = {"root": related_fields}
+
+                # Verificando quem é o dono do relacionamento, e recuperando o DTO relcaionado
+                # da forma correspondente
+                related_dto = None
+                if left_join_query.entity_relation_owner == EntityRelationOwner.OTHER:
+                    # Checking if pk_field exists
+                    if self._dto_class.pk_field is None:
+                        raise DTOListFieldConfigException(
+                            f"PK field not found in class: {self._dto_class}"
+                        )
+
+                    # Montando os filtros para recuperar o objeto relacionado
+                    related_filters = {
+                        left_join_query.left_join_fields[0].relation_field: getattr(
+                            dto, self._dto_class.pk_field
+                        )
+                    }
+
+                    # Recuperando a lista de DTOs relacionados (com um único elemento; limit=1)
+                    related_dto = service.list(
+                        None,
+                        1,
+                        related_fields,
+                        None,
+                        related_filters,
+                    )
+                    if len(related_dto) > 0:
+                        related_dto = related_dto[0]
+                    else:
+                        related_dto = None
+
+                elif left_join_query.entity_relation_owner == EntityRelationOwner.SELF:
+                    # Checking if pk_field exists
+                    if getattr(left_join_query.related_dto, "pk_field") is None:
+                        raise DTOListFieldConfigException(
+                            f"PK field not found in class: {left_join_query.related_dto}"
+                        )
+
+                    # Recuperando a PK da entidade relacionada
+                    related_pk = getattr(
+                        dto, left_join_query.left_join_fields[0].relation_field
+                    )
+
+                    if related_pk is None:
+                        continue
+
+                    # Recuperando o DTO relacionado
+                    related_dto = service.get(
+                        related_pk, partition_fields, related_fields
+                    )
+                else:
+                    raise Exception(
+                        f"Tipo de relacionamento (left join) não identificado: {left_join_query.entity_relation_owner}."
+                    )
+
+                # Copiando os campos necessários
+                for field in fields_necessarios:
+                    # Recuperando a configuração do campo left join
+                    left_join_field: DTOLeftJoinField = dto.left_join_fields_map[field]
+
+                    # Recuperando o valor da propriedade no DTO relacionado
+                    field_value = getattr(
+                        related_dto, left_join_field.related_dto_field
+                    )
+
+                    # Gravando o valor no DTO de interesse
+                    setattr(dto, field, field_value)
